Skip to content

Deployments ​

Created from an application for a specific environment, represents an actual deployment on a target.

Sources ​

Deployments can be created from a number of sources.

Archive (tar.gz) ​

An archive containing your project files to be deployed.

Raw file ​

A raw file. For example, a compose.yml content when using the Docker provider.

Git ​

A valid branch and an optional specific commit if the application has been configured with a version control system.