Skip to content

Frequently asked question ​

How does seelf know which services to expose from a compose.yml file? ​

See the providers page for more information.

Integrating seelf in your Continuous Integration / Continuous Deployment pipeline ​

See the CI / CD page for more information on how to do it.